@@ -7,6 +7,7 @@ import scipy as sp
 import time
 import gc
 import sklearn.metrics as mt
+import category_encoders as ce
 
 
 class _Folds:
@@ -20,9 +21,10 @@ class _Folds:
     def get_n_splits(self):
         return len(self.indices)
 
+
 # Class to hold and train many models (CB, XGB and LGB) on the same dataset
 class GBMFitter:
-    def __init__(self, cb_data=[], xgb_data=[], lgb_data=[], cv_strategy=None, cv_groups=None, use_rounders=False, metrics=['rmse'], verbose=1, logfile=None):
+    def __init__(self, cb_data=None, xgb_data=None, lgb_data=None, cv_strategy=None, cv_groups=None, use_rounders=False, metrics=['rmse'], verbose=1, logfile=None):
         """Generates models in a CV manner for all 3 libraries algorithms
 
         Inputs:
@@ -51,12 +53,11 @@ class GBMFitter:
         self.verbose = verbose
         self.logfile = logfile
 
-
     def _get_categorical_index(self, df, cat_cols):
         cat_features_index = np.where(df.columns.isin(cat_cols))[0].tolist()
         return cat_features_index
 
-    def fit(self, X, y, categorical=[], feature_selection=-1, skip_CB=False, skip_XGB=False, skip_LGB=False):
+    def fit(self, X, y, categorical=None, feature_selection=-1, skip_CB=False, skip_XGB=False, skip_LGB=False):
         """Generates models in a CV manner for all 3 libraries algorithms
 
         Inputs:
@@ -76,7 +77,7 @@ class GBMFitter:
         if not skip_LGB:
             self._fit('LGB', X, y, categorical, feature_selection)
 
-    def _fit(self, library, X, y, categorical=[], feature_selection=-1):
+    def _fit(self, library, X, y, categorical=None, feature_selection=-1):
         """ Fits data into the algorithms. Generates a model per fold, and stores a
         tuple of (model, rounder) into self.models for each fold.
 
@@ -174,6 +175,9 @@ class GBMFitter:
             y_pred_val = m.predict(X_val)
 
         if library == 'XGB':
+            if cat_features:
+                X_train = ce.one_hot.OneHotEncoder(cols=cat_features, drop_invariant=True).fit_transform(X_train)
+
             m = xgb.train(params=model_data['params'],
                           dtrain=xgb.DMatrix(X_train, y_train),
                           num_boost_round=num_boost_rounds,
